function s = chebyshev_parameter(l,r)
%CHEBYSHEV_PARAMETER Construct a parameter with a uniform weight function
%
% s = chebyshev_parameter() 
% s = chebyshev_parameter(l,r) 
%
% Generates a parameter on the interval [l,r] with a Chebyshev weight 
% function.
%
% See also PARAMETER, JACOBI_PARAMETER, HERMITE_PARAMETER

% Copyright 2009-2010 David F. Gleich (dfgleic@sandia.gov) and Paul G. 
% Constantine (pconsta@sandia.gov)
%
% History
% -------
% :2010-06-14: Initial release

if ~exist('l','var') || isempty(l), l=-1; end
if ~exist('r','var') || isempty(r), r=1; end

s = jacobi_parameter(l,r,-0.5,-0.5);
